@@ -32,14 +32,18 @@ class Package(ExtensionBase):
 
         .. versionadded::0.7.4
         """
-        if params.get("view", None) == "info":
+        view = params.get("view", "")
+        if view == "info":
             # The 'info' view is strict about parameter validation
             return {key: value for key, value in params.items()
                     if key in ["parse", "arch", "repository", "view"]}
-
+        if "productlist" in view:
+            # The "deleted" parameter seems to have precedence over other acceptable parameters
+            # (e.g. "view")
+            return {key: value for key, value in params.items() if key not in ["deleted"]}
         return params
 
-    def get_list(self, project: str, deleted: bool = False, expand: bool = True, **params):
+    def get_list(self, project: str, deleted: bool = False, expand: bool = False, **params):
         """
         Get packages from project
 
@@ -52,6 +56,9 @@ class Package(ExtensionBase):
         .. versionadded:: 0.7.4
             Parameter ``params``
 
+        .. versionchanged:: 0.7.6
+            Changed default value of ``expand`` to ``False``
+
         :param project: name of project
         :param deleted: Show deleted packages instead
         :param expand: Include inherited packages and their project of origin
